@@ -477,8 +477,8 @@ Pick (int n)
 	appData.pieceToCharTable = NULL;
 	appData.pieceNickNames = "";
 	appData.colorNickNames = "";
-	Reset(True, True);
         PopDown(TransientDlg);
+	Reset(True, True);
         return;
 }
 
@@ -1167,7 +1167,8 @@ IcsKey (int n)
       case -1:
 	val = NextInHistory();
     }
-    SetWidgetText(&boxOptions[0], val ? val : "", InputBoxDlg);
+    SetWidgetText(&boxOptions[0], val = val ? val : "", InputBoxDlg);
+    SetInsertPos(&boxOptions[0], strlen(val));
 }
 
 static void
@@ -1229,8 +1230,8 @@ PopUpMoveDialog (char firstchar)
 void
 BoxAutoPopUp (char *buf)
 {
+	if(!appData.autoBox) return;
 	if(appData.icsActive) { // text typed to board in ICS mode: divert to ICS input box
-	    if(!appData.autoBox) return;
 	    if(DialogExists(InputBoxDlg)) { // box already exists: append to current contents
 		char *p, newText[MSG_SIZ];
 		GetWidgetText(&boxOptions[0], &p);
@@ -1697,7 +1698,7 @@ ChatSwitch (int n)
 void
 ChatProc ()
 {
-    if(GenericPopUp(chatOptions, _("Chat box"), ChatDlg, BoardWindow, NONMODAL, 0))
+    if(GenericPopUp(chatOptions, _("Chat box"), ChatDlg, BoardWindow, NONMODAL, appData.topLevel))
 	AddHandler(&chatOptions[0], ChatDlg, 2), AddHandler(&chatOptions[6], ChatDlg, 2); // treats return as OK
     MarkMenu("View.OpenChatWindow", ChatDlg);
 }
@@ -1874,7 +1875,7 @@ DisplayMoveError (String message)
 {
     fromX = fromY = -1;
     ClearHighlights();
-    DrawPosition(FALSE, NULL);
+    DrawPosition(TRUE, NULL); // selective redraw would miss the from-square of the rejected move, displayed empty after drag, but not marked damaged!
     if (appData.debugMode || appData.matchMode) {
 	fprintf(stderr, "%s: %s\n", programName, message);
     }
@@ -2469,12 +2470,12 @@ ListDir (int pathFlag)
 		ASSIGN(fileList[filePtr], s); filePtr++;
 	    }
 	}
-	if(filePtr == MAXFILES-2) { ASSIGN(fileList[filePtr], _("\177 next page")); filePtr++; }
+	if(filePtr == MAXFILES-2) { ASSIGN(fileList[filePtr], _("  next page")); filePtr++; }
 	FREE(folderList[folderPtr]); folderList[folderPtr] = NULL;
 	FREE(fileList[filePtr]); fileList[filePtr] = NULL;
 	closedir(dir);
 	extFlag = 0;         qsort((void*)folderList, folderPtr, sizeof(char*), &Comp);
-	extFlag = byExtension; qsort((void*)fileList, filePtr, sizeof(char*), &Comp);
+	extFlag = byExtension; qsort((void*)fileList, filePtr < MAXFILES-2 ? filePtr : MAXFILES-2, sizeof(char*), &Comp);
 }
 
 void
@@ -2505,7 +2506,7 @@ Switch (int n)
 {
     if(byExtension == (n == 4)) return;
     extFlag = byExtension = (n == 4);
-    qsort((void*)fileList, filePtr, sizeof(char*), &Comp);
+    qsort((void*)fileList, filePtr < MAXFILES-2 ? filePtr : MAXFILES-2, sizeof(char*), &Comp);
     LoadListBox(&browseOptions[6], "", -1, -1);
 }
 
@@ -2525,7 +2526,7 @@ SetTypeFilter (int n)
 void
 FileSelProc (int n, int sel)
 {
-    if(sel<0) return;
+    if(sel < 0 || fileList[sel] == NULL) return;
     if(sel == MAXFILES-2) { pageStart = cnt; Refresh(-1); return; }
     ASSIGN(fileName, fileList[sel]);
     if(BrowseOK(0)) PopDown(BrowserDlg);
