@@ -5,7 +5,7 @@
  * Massachusetts. 
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
@@ -106,7 +106,7 @@ VOID InitAppData(LPSTR);
 VOID InitDrawingColors(VOID);
 VOID InitDrawingSizes(BoardSize boardSize, int flags);
 VOID InitMenuChecks(VOID);
-VOID ICSInitScript(VOID);
+int  ICSInitScript(VOID);
 BOOL CenterWindow(HWND hwndChild, HWND hwndParent);
 VOID ResizeEditPlusButtons(HWND hDlg, HWND hText, int sizeX, int sizeY, int newSizeX, int newSizeY);
 VOID PromotionPopup(HWND hwnd);
@@ -139,6 +139,7 @@ VOID TourneyPopup();
 VOID LoadEnginePopUp();
 VOID LoadOptionsPopup(HWND hDlg);
 VOID InitTextures();
+void ThemeOptionsPopup(HWND hwnd);
 
 /* Constants */
 
@@ -215,3 +216,4 @@ extern HWND gameListDialog;
 
 VOID EditTagsProc(void);
 extern HWND editTagsDialog;
+extern int screenWidth, screenHeight;
